function draw_visibility( xs, ys, alphas, betas, radius)

    % Helper function to calculate points of circle
    function [px, py] = getPoints(i)
        x=xs(i);
        y=ys(i);
        if length(alphas)<i % If angles not given, assume omni
            alpha=0;
            beta=2*pi;
        else
            alpha=alphas(i);
            beta=betas(i); 
        end
        t = linspace(alpha, beta, 50);
        a = radius * cos(t);
        b = radius * sin(t);
        % Draw lines connecting to the center if not full circle
        if abs(alpha-beta)==2*pi
            px = a+x;
            py = b+y;
        else
            px = [0 a]+x;
            py = [0 b]+y;
        end
    end

    % Get points of all circles
    n=length(xs);
    pxs = cell(n,1);
    pys = cell(n,1);
    for i=1:n
       [pxs{i}, pys{i}] = getPoints(i);
    end

    % Draw insides
    hold on;
    for i=1:n
        fill(pxs{i}, pys{i}, 'k', ...
            'FaceColor',[0.9, 0.9, 0.9], ...
            'EdgeColor', [0.8, 0.8, 0.8]);
    end
    % Draw edges
    for i=1:n
        fill(pxs{i}, pys{i}, 'k', ...
            'FaceColor','none', ...
            'EdgeColor', [0.8, 0.8, 0.8]);
    end
    % Draw the points
    cm = colormap('Lines');
    for i=1:n
        x=xs(i);
        y=ys(i);
        rectangle('Position', [x-0.025, y-0.025, 0.05, 0.05], ...
            'Curvature', [1 1],...
            'FaceColor', cm(i,:), ...
            'EdgeColor', 'k', ...
            'LineWidth', 2);
    end
       
    hold off;

end


