function formation(a1, a2)
% Usage:
% formation(fileName)
% formation(radius, angle)

    % Parse arguments
    if nargin==0
        fileName='';
        radius=0.2;
        angle=90;        
    elseif nargin==1
        fileName=a1;
        radius=0;
        angle=0;
    elseif nargin==2
        fileName='';
        radius=a1;
        angle=a2;
    end

    % Prepare the plot
    prepare_world

    if (isempty(fileName))
        % Get formation
        [u,v] = get_formation;
        n=length(u);

        % Get agents
        [x0, y0, alpha0, beta0] = get_agents(radius, angle, n);
    else
       load(['data/' fileName '.mat']);
    end

    % Save to temporary file
    save('data/current_formation.mat', ...
        'radius', 'angle', 'x0', 'y0', 'alpha0', 'beta0', 'u', 'v');
    
    % Graph parameters
    A=adjacency(x0, y0, alpha0, beta0, radius);
    L=laplacian(A);

    % Draw the graph
    draw_visibility(x0, y0, alpha0, beta0, radius); 
    draw_graph(x0, y0, A);
    
    % Is connected?
    is_connected(L);

    % Simulate
    sys=system_formation(L);
    [X,Y] = simulate(sys, x0, y0, u, v);

    % Draw trajectories
    draw_trajectories(X,Y)
    press_space

    % Animate
    animate_static(X, Y, A);
    
end
