function [ xs, ys, alphas, betas ] = get_agents(radius, angle, numPts)

    function set_title(n)
        if (n==0)
            title('');
        elseif (n>0)
            if (angle==360)
                title(['Select positions of ' num2str(n) ' agents']);
            else
                title(['Select positions and orientations of ' num2str(n) ' agents']);
            end
        else
            if (angle==360)
                title('Select agent positions and press Enter');
            else
                title('Select agent positions and orientations and press Enter');
            end
        end
    end   

    % Setup
    if (nargin<3)
       numPts=-1; 
    end
    xs=[];
    ys=[];
    alphas=[];
    betas=[];
    
    % Get points    
    for i=1:50
        % Get a position
        set_title(numPts-i+1)

        
        if (numPts>0) && (length(xs)==numPts)
            press_space
            break;
        end
        
        [x,y]=ginput(1);
        if (length(x)<1)
            break
        end
        xs=[xs;x];
        ys=[ys;y];
               
        % Draw visibility
        prepare_world
        set_title(numPts-i+1);
        draw_visibility(xs, ys, alphas, betas, radius); 

        % Get orientation if not omnidirectional
        if angle~=360
            [x,y]=ginput(1);
            alpha=0;
            beta=2*pi;
            if (length(x)>0)
                % Calculate alpha and beta from orientation
                xdiff=x-xs(end);
                ydiff=y-ys(end);
                gamma=atan2(ydiff, xdiff);
                if (gamma<0)
                    gamma=gamma+2*pi;
                end
                alpha=gamma-((angle/180)*pi)/2;
                beta=gamma+((angle/180)*pi)/2;
            end
            alphas=[alphas;alpha];
            betas=[betas;beta];
               
            % Draw visibility
            prepare_world
            set_title(numPts-i+1)
            draw_visibility(xs, ys, alphas, betas, radius); 
        else
            alphas=[alphas;0];
            betas=[betas;2*pi];
        end
        
        % Calculate graph structure
        A=adjacency(xs, ys, alphas, betas, radius);

        % Draw graph
        draw_graph(xs, ys, A);
    end

end

